%fraunhofer_single_slit
% Plots Fraunhofer 'far field' diffraction pattern of a uniformly
% illuminated grating comprised of uniformly spaced fixed width slits
%
% LAST UPDATED by Andy French 8/11/15

function fraunhofer_grating

%Set wavelength /nm
%http://science-edu.larc.nasa.gov/EDDOCS/Wavelengths_for_Colors.html
lamda = 400;  %Violet
lamda = 445;  %Indigo
lamda = 475;  %Blue
lamda = 510;  %Green
lamda = 570;  %Yellow
lamda = 590;  %Orange
lamda = 650;  %Red

%Convert to m
lamda = lamda*1e-9;

%Slit spacing /m
s = 3*lamda;

%Slit width
w = 2*lamda;

%Define number of slits
N = 5;

%Set fontsize
fsize = 18;

%Wavenumber /m^-1
k = 2*pi/lamda;

%Speed of light /ms^-1
c = 2.998e8;

%Calculate frequency /Hz
f = c/lamda;

%Calculate far-field range limit /m
r_far_field = N*s/lamda;

%Set angles
theta = linspace( -pi/2,pi/2,1000);

%Determine intensity pattern amplitude variation with angle (i.e. range is
%the same)
I_s = ( sinN( 0.5*k*s*sin(theta),N) ).^2;
I_w = ( sinc( 0.5*k*w*sin(theta))  ).^2;
I = I_s.*I_w;

%Determine zeros angles (degrees)
nmax = floor(w/lamda);
if nmax>0
    theta_zero1 = (180/pi)*asin((1:nmax)*lamda/w);
    theta_zero1 = [-fliplr(theta_zero1),theta_zero1];
end
mmax = floor(N*s/lamda);
if mmax>0
    theta_zero2 = (180/pi)*asin((1:mmax)*lamda/(N*s));
    theta_zero2 = [-fliplr(theta_zero2),theta_zero2];
end
theta_zero = sort( [theta_zero1,theta_zero2] );

%Determine grating lobes
qmax = floor(s/lamda);
if mmax>0
    theta_max = (180/pi)*asin((0:qmax)*lamda/(s));
    theta_max = [-fliplr(theta_max),theta_max];
end

%Plot intensity pattern (i.e. wave power)
plot( theta*180/pi, I_w,'r--' );
hold on;
plot( theta*180/pi, I,'b-' );
plot(theta_zero,zeros(size(theta_zero)),'r*');
plot(theta_max,zeros(size(theta_max)),'g*');
xlabel( '\theta^o', 'fontsize',fsize );
ylabel('Normalized wave power','fontsize',fsize )
title({'Grating Fraunhofer far field diffraction',['\lambda = ',...
    num2str(lamda/1e-9),'nm,  s = ',num2str(s/lamda),...
    '\lambda, w = ',num2str(w/lamda),'\lambda, N = ',num2str(N)]},'fontsize',fsize);
xlim([-90,90])
grid on;
set(gca,'fontsize',fsize);
print( gcf,'fraunhofer grating.png','-dpng','-r300');
clf;

%Plot intensity pattern (i.e. wave power)in dBm
plot( theta*180/pi, dBm(I) );
hold on;
for n=1:length(theta_zero)
    plot( [theta_zero(n),theta_zero(n)],[-60,0] ,'r-' );
end
for n=1:length(theta_max)
    plot( [theta_max(n),theta_max(n)],[-60,0] ,'g-' );
end
xlabel( '\theta^o', 'fontsize',fsize );
ylabel('Normalized wave power /dBm','fontsize',fsize )
title({'Grating Fraunhofer far field diffraction',['\lambda = ',...
    num2str(lamda/1e-9),'nm,  s = ',num2str(s/lamda),...
    '\lambda, w = ',num2str(w/lamda),'\lambda, N = ',num2str(N)]},'fontsize',fsize);
xlim([-90,90])
ylim([-60,0])
grid on;
set(gca,'fontsize',fsize);
print( gcf,'fraunhofer grating dB.png','-dpng','-r300');
close(gcf);

%%

function y = sinc(x)
y = ones(size(x));
k = x~=0;
y(k) = sin(x(k))./x((k));

%%

function y = sinN(x,N)
y = N*ones(size(x));
k = x~=0;
y(k) = sin(N*x(k))./(N*sin(x(k)));

%%

function y = dBm(x)
y = NaN(size(x));
k = x>0;
y(k) = 10*log10(x);
y = y - max(y);

%End of code
